pub trait Poppable {
// Required method
fn pop(&mut self) -> bool;
}Expand description
Something poppable Path-like
This trait provides the pop method, which does the same as
PathBuf::pop. However, the trait is implemented for a number of different
types that implement AsRef<Path>.